import babel from 'rollup-plugin-babel'
import typescript from 'rollup-plugin-typescript2'
import resolve from 'rollup-plugin-node-resolve'
import external from 'rollup-plugin-peer-deps-external'

import pkg from './package.json'

const input = 'src/index.ts'

const isExternal = id => !id.startsWith('.') && !id.startsWith('/')

const getBabelOptions = ({ useESModules }) => ({
  exclude: 'node_modules/**',
  runtimeHelpers: true,
  plugins: [['@babel/plugin-transform-runtime', { useESModules }]]
})

const umd = {
  input,
  output: {
    file: 'dist/index.umd.js',
    format: 'umd',
    name: 'ReactTensorflow',
    globals: {
      tf: '@tensorflow/tfjs',
      react: 'React'
    }
  },
  external: ['react', '@tensorflow/tfjs'],
  plugins: [
    external(),
    resolve(),
    typescript({
      rollupCommonJSResolveHack: true,
      exclude: '**/__test__/**',
      clean: true
    }),
    babel(getBabelOptions({ useESModules: true }))
  ]
}

const es = {
  input,
  output: { file: pkg.module, format: 'es' },
  external: ['react', '@tensorflow/tfjs'],
  plugins: [
    external(),
    typescript({
      rollupCommonJSResolveHack: true,
      exclude: '**/__test__/**',
      clean: true
    }),
    babel(getBabelOptions({ useESModules: true }))
  ]
}

const cjs = {
  input,
  output: { file: pkg.main, format: 'cjs' },
  external: ['react', '@tensorflow/tfjs'],
  plugins: [
    external(),
    typescript({
      rollupCommonJSResolveHack: true,
      exclude: '**/__test__/**',
      clean: true
    }),
    babel(getBabelOptions({ useESModules: false }))
  ]
}

export default [umd, es, cjs]
